Voltage

Enum Voltage 

#[non_exhaustive]
pub enum Voltage { V1P8, V3P3, }
SD-Card voltage

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


V1P8

(ESP32P4 only) Use 1.8V IO voltage for UHS-I speed This means the user has to provide an external LDO power supply or to enable and configure an internal LDO via the sdkconfig setting “SD/MMC Example Configuration -> SD power supply comes from internal LDO IO”



V3P3

Use 3.3V IO voltage for speeds below UHS-I The only supported conf for MCUs other than ESP32P4